@@ -1738,6 +1738,8 @@ class ServiceEndpointTypes(enum.Enum):
     SAGEMAKER_RUNTIME = "SAGEMAKER_RUNTIME"
     SECRETS_MANAGER = "SECRETS_MANAGER"
     SSM = "SSM"
+    ECR_API = "ECR_API"
+    ECR_DKR = "ECR_DKR"
     EVENTS = "EVENTS"
 
 
