@@ -16,6 +16,8 @@ import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_ecr._jsii
+import aws_cdk.aws_ecs._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_elasticloadbalancingv2_targets._jsii
 import aws_cdk.aws_elasticsearch._jsii
@@ -45,9 +47,9 @@ import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/core",
-    "1.134.0",
+    "1.145.0",
     __name__[0:-6],
-    "core@1.134.0.jsii.tgz",
+    "core@1.145.0.jsii.tgz",
 )
 
 __all__ = [
